import { aws_ec2 as ec2, aws_rds as rds, aws_lambda as lambda, aws_secretsmanager as secretsmanager } from "aws-cdk-lib";
import { IDomainName } from "@aws-cdk/aws-apigatewayv2-alpha";
import { Construct } from "constructs";
import { CustomLambdaFunctionProps } from "../utils";
export declare const EXTENSIONS: {
    readonly QUERY: "query";
    readonly SORT: "sort";
    readonly FIELDS: "fields";
    readonly FILTER: "filter";
    readonly FREE_TEXT: "free_text";
    readonly PAGINATION: "pagination";
    readonly COLLECTION_SEARCH: "collection_search";
    readonly TRANSACTION: "transaction";
    readonly BULK_TRANSACTION: "bulk_transactions";
};
type ExtensionType = (typeof EXTENSIONS)[keyof typeof EXTENSIONS];
export declare class PgStacApiLambda extends Construct {
    readonly url: string;
    stacApiLambdaFunction: lambda.Function;
    constructor(scope: Construct, id: string, props: PgStacApiLambdaProps);
}
export interface PgStacApiLambdaProps {
    /**
     * VPC into which the lambda should be deployed.
     */
    readonly vpc?: ec2.IVpc;
    /**
     * RDS Instance with installed pgSTAC or pgbouncer server.
     */
    readonly db: rds.IDatabaseInstance | ec2.IInstance;
    /**
     * Subnet into which the lambda should be deployed.
     */
    readonly subnetSelection?: ec2.SubnetSelection;
    /**
     * Secret containing connection information for pgSTAC database.
     */
    readonly dbSecret: secretsmanager.ISecret;
    /**
     * Customized environment variables to send to fastapi-pgstac runtime.
     */
    readonly apiEnv?: Record<string, string>;
    /**
     * Custom Domain Name Options for STAC API,
     */
    readonly stacApiDomainName?: IDomainName;
    /**
     * List of STAC API extensions to enable.
     *
     * @default - query, sort, fields, filter, free_text, pagniation, collection_search
     */
    readonly enabledExtensions?: ExtensionType[];
    /**
     * Can be used to override the default lambda function properties.
     *
     * @default - defined in the construct.
     */
    readonly lambdaFunctionOptions?: CustomLambdaFunctionProps;
}
export {};
